﻿using System.Collections.Generic;
using System.Linq;

namespace Rendszerhiba_Újratöltve
{
    /// <summary>
    /// IHTML elemeket tárol és ki tudja írni azok tartalmát.
    /// </summary>
    abstract class ÖsszetettHTMLElem : IHTMLElem
    {
        /// <summary>
        /// Létrehoz egy <see cref="T:Rendszerhiba_Újratöltve.ÖsszetettHTMLElem"/> osztályt.
        /// </summary>
        /// <param name="elemek">A bennefoglalt IHTMLElem-ek</param>
        protected ÖsszetettHTMLElem(IEnumerable<IHTMLElem> elemek)
        {
            Elemek = elemek;
        }

        /// <summary>
        /// IHTMLElem-ek tárolása fa szerkezet létrehozásához.
        /// </summary>
        protected IEnumerable<IHTMLElem> Elemek
        {
            get;
            private set;
        }

        /// <summary>
        /// A magában foglalt HTML-elemek kiírása.
        /// </summary>
        /// <returns></returns>
        protected string KiírTartalamat()
        {
            return string.Join(Elválasztó,
                from elem in Elemek
                select elem.Kiír());
        }

        /// <summary>
        /// Elemek közti elválasztás a HTML kiíratásakor.
        /// </summary>
        protected virtual string Elválasztó
        {
            get
            {
                return "";
            }
        }

        /// <summary>
        /// A HTML kiírása a KiírTartalmat felhasználásával.
        /// </summary>
        /// <returns></returns>
        public abstract string Kiír();
    }
}
